## ----defClass------------------------------------------------------------
a <- c(3, 4, 5); class(a)

## ----matrixDef-----------------------------------------------------------
A <- matrix(0, ncol=3, nrow=2); A
B <- matrix(1:10, ncol=5); B

## ----matrixDef2----------------------------------------------------------
C <- matrix(c("A", 1:9), ncol=5, byrow=TRUE); C
C[2,3] <- 1; C

## ----matrixSubset--------------------------------------------------------
B
B[1,]
B[,2:3]

## ----operations----------------------------------------------------------
B[,1:2]+B[,3:4]
B*B

## ----matOperations-------------------------------------------------------
B%*%t(B); tcrossprod(B,B) # faster
crossprod(B,B)

## ----matOperations2------------------------------------------------------
crossprod(B,B)
outer(B[,1], B[,2])

## ----matOperations3------------------------------------------------------
D <- crossprod(B)
resEigen <- eigen(D)
resEigen$values
all.equal(resEigen$vectors%*%
            diag(resEigen$values)%*%
            t(resEigen$vectors),
          D)

## ----matFunctions--------------------------------------------------------
ncol(B); nrow(B); dim(B)
mode(B); mode(C)

## ----matFunctions2-------------------------------------------------------
rowSums(B); colSums(B)
colnames(B)
rownames(B) <- 1:nrow(B); rownames(B)

## ----rowColFunction------------------------------------------------------
apply(B, 1, sum); apply(B, 2, sum)
apply(B, 2, as.character)

## ----rowColFunction2-----------------------------------------------------
sweep(B, 1, rep(2,nrow(B)), "+")
sweep(B, 1, rowSums(B), "/")

## ----arrayDef------------------------------------------------------------
E <- array(1:20, c(2,5,2)); E

## ----ex1-----------------------------------------------------------------
vect <- 1:6

## ----res-ex1, echo=FALSE-------------------------------------------------
outer(vect, rep(1,3))
outer(rep(1,3), vect)

## ----ex2-----------------------------------------------------------------
data(Titanic)
cont <- t(apply(Titanic, c(1,4), sum)); cont

## ----ex2-res, echo=FALSE, results='hide'---------------------------------
sweep(cont, 2, colSums(cont), "/")

## ----dfDef---------------------------------------------------------------
df <- data.frame(nom=c("Nathalie",
                       "Madalina",
                       "Nicolas"),
                 age=c(38,34,31))
df

## ----dfClass-------------------------------------------------------------
class(df); sapply(df, class)

## ----subset--------------------------------------------------------------
names(df)
df[,2]; df$age

## ----subset2-------------------------------------------------------------
df[1,]
df[df$age>32,]; subset(df, age>32, c("nom"))

## ----dfExploration-------------------------------------------------------
data(iris);
dim(iris); names(iris); sapply(iris,class)

## ----dfExploration2------------------------------------------------------
summary(iris[,3:5])

## ----Stat----------------------------------------------------------------
min(iris$Sepal.Width); max(iris$Sepal.Width)
mean(iris$Sepal.Width)
median(iris$Sepal.Width)

## ----Stat2---------------------------------------------------------------
range(iris$Sepal.Width)
sd(iris$Sepal.Width); var(iris$Sepal.Width)
quantile(iris$Sepal.Width, c(0,0.25,0.5,0.75,1))

## ----Stat3---------------------------------------------------------------
table(iris$Species)
iris$Large <- factor(iris$Sepal.Width>3)
table(iris$Species,iris$Large)

## ----dfOperations--------------------------------------------------------
apply(iris[,1:4], 2, mean)
s.iris <- sweep(iris[,1:4], 2,
                apply(iris[,1:4],2,mean),
                "-")
head(s.iris[,1:2], 3)

## ----dfOperations3-------------------------------------------------------
apply(s.iris, 2, mean)
s2.iris <- scale(iris[,1:2])
apply(s2.iris,2,mean); apply(s2.iris,2,sd)

## ----condStat------------------------------------------------------------
by(iris$Sepal.Length, iris$Species, mean)

## ----condStat2-----------------------------------------------------------
tapply(iris$Sepal.Length, iris$Species, sd)
head(tapply(iris$Sepal.Length, iris$Species,
            quantile, probs=c(0.25,0.75)), 2)

## ----ex3-----------------------------------------------------------------
data(airquality)

## ----ex3-res, echo=FALSE, results='hide'---------------------------------
dim(airquality)

## ----ex3-res2, echo=FALSE, results='hide'--------------------------------
names(airquality)
sapply(airquality, class)

## ----ex3-res3, echo=FALSE, results='hide'--------------------------------
summary(airquality)

## ----ex3-res4, echo=FALSE, results='hide'--------------------------------
sum(airquality$Temp>80)
apply(subset(airquality, Temp>80, c("Ozone","Wind")), 2, mean, na.rm=TRUE)

## ----ex3-res5, echo=FALSE, results='hide'--------------------------------
tapply(airquality$Ozone, airquality$Month, mean, na.rm=TRUE)

## ----listDef-------------------------------------------------------------
a.list <- list("name"="a list", "matrix"=B,
               "dataframe"=df); a.list

## ----listBasics----------------------------------------------------------
class(a.list)
length(a.list)
names(a.list)

## ----listBasics2---------------------------------------------------------
lapply(a.list, class)

## ----listBasics3---------------------------------------------------------
lapply(a.list, length)

