## ----parGraphics, fig.width=20-------------------------------------------
data(airquality)
par(bg="lightyellow", mfcol=c(1,2), pch="+")
plot(airquality$Ozone)
plot(factor(airquality$Month))

## ----exportGraphics, results="hide"--------------------------------------
png("myFistGraphic.png", width=600,
    height=600)
par(bg="transparent", lty=2, lwd=2, 
    col="darkred")
plot(airquality$Wind, airquality$Ozone)
dev.off() # close the graphics device

## ----exportGraphics2, fig.width=5, fig.height=3--------------------------
par(bg="transparent", lty=2, lwd=2,
    mar=rep(2,4), col="darkred")
plot(airquality$Wind, airquality$Ozone)
dev.print(png, file="mySecondGraphic.png",
          width=600, height=600)

## ----plot1NumVar, results='hide', fig.height=4---------------------------
plot(airquality$Ozone, type="l")

## ----plot1NumVar2, results='hide', fig.height=5, fig.width=10------------
plot(airquality$Ozone, main="Ozone",
     type="b", pch=19, col="darkred")

## ----plot1nonNumVar, results='hide', fig.height=5, fig.width=10----------
plot(factor(airquality$Month), main="Month",
     col="pink", lwd=2, las=3, 
names=c("May","June","July","Aug.","Sept"))

## ----plot2NumVar, results='hide', fig.height=5, fig.width=10-------------
par(mfrow=c(1,2))
plot(airquality$Wind, airquality$Ozone)
plot(airquality$Ozone~airquality$Wind)

## ----plot2nonNumNumVar, results='hide', fig.height=5, fig.width=10-------
par(mfrow=c(1,2))
plot(airquality[,3], factor(airquality[,5]))
plot(factor(airquality[,5]), airquality[,3])

## ----plot2nonNumNumVar2, results='hide', fig.height=5, fig.width=10------
par(mfrow=c(1,2))
plot(airquality[,3]~factor(airquality[,5]))
plot(factor(airquality[,5])~airquality[,3],
col=rainbow(nlevels(factor(airquality[,5]))))

## ----plot2nonNumVar, results='hide', fig.height=5, fig.width=10----------
plot(factor(airquality[,5]),
     factor(airquality[,1]>30), col=c(3,2),
     xlab="Month", ylab="Bad quality")

## ----boxplot1------------------------------------------------------------
boxplot(airquality$Wind, ylab="Wind speed",
        main="Wind speed distribution")

## ----boxplot2------------------------------------------------------------
boxplot(airquality$Wind~
          factor(airquality$Month),
        ylab="Wind speed", 
names=c("May","June","July","Aug.","Sept."))

## ----hist1, fig.width=20-------------------------------------------------
par(mfrow=c(1,2))
hist(airquality$Ozone, breaks=20)
hist(airquality$Ozone, col="pink",
     breaks=c(0,10,20,40,60,80,100,170))

## ----barplot1, results='hide'--------------------------------------------
barplot(table(airquality$Month),
        ylab="Frenquency", col="lightblue")

## ----barplot2------------------------------------------------------------
barplot(table(airquality$Ozone>50,
              airquality$Month),
        ylab="Frenquency",
        col=c("lightgreen", "pink"))

## ----barplot2b-----------------------------------------------------------
CT <- table(airquality$Ozone>50,
            airquality$Month)
barplot(sweep(CT, 2, colSums(CT), "/"),
        ylab="Frenquency",
        col=c("lightgreen", "pink"))

## ----pie1----------------------------------------------------------------
pie(table(airquality$Month), col=rainbow(5),
    main="Months",
    labels=paste(round(table(airquality$Month)/
      nrow(airquality),2),"%"))

## ----vhLines, fig.width=15-----------------------------------------------
plot(airquality$Ozone, type="h")
abline(h=50, col="darkred", lty=2, lwd=2)
abline(v=50, col="darkblue", lwd=2)

## ----vhLines2, fig.width=15----------------------------------------------
plot(airquality$Ozone~airquality$Wind)
abline(0, 1, col="darkgreen")

## ----lines, fig.width=15-------------------------------------------------
plot(airquality$Wind[1:100], col="darkred",
     type="l")
lines(25:78, airquality$Wind[100:153],
      col="darkgreen")

## ----segments, fig.width=15----------------------------------------------
plot(airquality$Ozone~airquality$Wind)
segments(airquality[1:5,3],
         airquality[1:5,1],
         airquality[141:145,3],
         airquality[141:145,1], col="darkred")

## ----arrows, fig.width=15------------------------------------------------
plot(airquality$Ozone~airquality$Wind)
arrows(airquality[1:5,3],
       airquality[1:5,1],
       airquality[141:145,3],
       airquality[141:145,1],
       col="darkred")

## ----points, fig.width=15------------------------------------------------
plot(airquality$Ozone, type="l")
points(airquality$Wind, pch=19)

## ----points2, fig.width=15-----------------------------------------------
plot(airquality$Temp~airquality$Wind,
     pch=19)
points(airquality$Wind, airquality$Ozone, 
       col="darkred", pch=19)

## ----points3, fig.width=15-----------------------------------------------
plot(airquality$Temp~airquality$Wind,
     pch=19,
     ylim=range(airquality$Ozone,
                na.rm=TRUE))
points(airquality$Wind, airquality$Ozone, 
       col="darkred", pch=19)

## ----text, fig.width=15--------------------------------------------------
plot(airquality$Temp, type="l")
text(90, 70, "It's much\n too hot",
     cex=3, col="darkred")
text(0, 90, "Too cold...", col="blue", cex=3,
     pos=4) # pos=4 <=> "to the right of"

## ----legend, fig.width=15------------------------------------------------
barplot(table(factor(airquality$Ozone>50),
              factor(airquality$Month)),
        col=c(3,2))
legend(1.5, 20, cex=2, pch=15, 
       legend=c("good","bad"), col=c(3,2))

## ----legend2, fig.width=15-----------------------------------------------
par(mfrow=c(1,2))
barplot(table(factor(airquality$Ozone>50),
              factor(airquality$Month)),
        col=c(3,2))
plot.new()
legend("center", cex=4, pch=15, 
       legend=c("good","bad"), col=c(3,2))

## ----ex1-----------------------------------------------------------------
data(CO2)

## ----ex1-boxplot, echo=FALSE---------------------------------------------
par(bg="white")
boxplot(CO2$uptake, main="Uptake rate distribution", horizontal=TRUE)

## ----ex1-scatter, echo=FALSE---------------------------------------------
par(bg="white")
plot(CO2$uptake~CO2$conc, main="Uptake rate versus\n CO2 concentration",
     pch="+", xlab="CO2 concentration", ylab="Uptake rate", col="darkred")

## ----ex1-barplot, echo=FALSE, fig.width=15-------------------------------
par(bg="white", mfrow=c(1,2))
barplot(table(CO2$Type,CO2$Treatment), col=c("darkblue","darkgreen"),
        names=c("not chilled", "chilled"))
plot.new()
legend("center", cex=4, pch=19, col=c("darkblue","darkgreen"), 
       legend=c("Quebec", "Mississippi"))

## ----ex1-condBox, echo=FALSE, fig.width=15-------------------------------
par(bg="white")
plot(CO2$uptake~CO2$Type, ylab="uptake rate", xlab="plant type", col="pink")

