## ----densGaussian, fig.width=15, fig.height=4----------------------------
dnorm(0.5); dnorm(c(-0.5,0,0.5))
curve(dnorm, xlim=c(-3,3))

## ----cumDistGaussian, fig.width=15, fig.height=4-------------------------
pnorm(0.5); pnorm(c(-0.5,0,0.5))
curve(pnorm, xlim=c(-3,3))

## ----invGaussian, fig.width=15-------------------------------------------
qnorm(0.975) # quantile of order 97.5%
curve(qnorm, xlim=c(0,1))

## ----densPois, fig.width=15----------------------------------------------
dpois(1, lambda=3)
barplot(dpois(1:10, lambda=3), col="darkred",
        names=1:10)

## ----cumDensPois, fig.width=15-------------------------------------------
ppois(1, lambda=3)
barplot(ppois(1:10, lambda=3), col="darkred",
        names=1:10)

## ----invPois, fig.width=15-----------------------------------------------
qpois(0.95, lambda=3) # quantile of order 95%
x <- seq(0,1,length=1000)
plot(x, qpois(x,lambda=3), type="h")

## ----random--------------------------------------------------------------
sample(1:12, 5, replace=FALSE)
sample(1:12, 20, replace=TRUE)

## ----random2, fig.width=15-----------------------------------------------
rnorm(3); hist(rnorm(50, mean=2, sd=3))

## ----random3, fig.width=15-----------------------------------------------
hist(rnorm(1000), col="darkred", freq=FALSE)
curve(dnorm, lwd=4, col="green", add=TRUE)

## ----reprodRand----------------------------------------------------------
rnorm(3) # varies each time it is called
set.seed(2807); rnorm(3)

## ----normalTests---------------------------------------------------------
to.test <- rnorm(100, mean=5)
shapiro.test(to.test)

## ----normalTests2--------------------------------------------------------
to.test <- runif(100)
res <- ks.test(to.test, "dnorm")
res; res$statistic; res$p.value

## ----studentTests--------------------------------------------------------
to.test <- rnorm(100, mean=5)
t.test(to.test, mu=5)

## ----studentTests2-------------------------------------------------------
to.test <- rnorm(100)
to.test2 <- rnorm(100, mean=1)
res <- t.test(to.test, to.test2, var.equal=TRUE)
res$p.value; res$statistic; qt(c(0.025,0.975), df=99)

## ----wilcoxTest----------------------------------------------------------
to.test <- rnorm(100); to.test2 <- runif(200)
wilcox.test(to.test, to.test2)

## ----chi2Test------------------------------------------------------------
CT <- as.table(rbind(c(762, 327, 468),
                    c(484, 239, 477)))
dimnames(CT) <- list(gender = c("M","F"),
                    party =
c("Democrat","Independent", "Republican"))
res <- chisq.test(CT)  ; res

## ----chi2Test2-----------------------------------------------------------
names(res)
res$expected

## ----fit-----------------------------------------------------------------
data(airquality)
res <- lm(Ozone~Wind, data=airquality); res

## ----interpretation------------------------------------------------------
names(res)
res$coefficients

## ----interpretation2-----------------------------------------------------
head(res$fitted)
head(res$residuals)
cor(airquality$Ozone, airquality$Wind,
    use="complete.obs")

## ----plotLM--------------------------------------------------------------
par(mfrow=c(2,2))
plot(res)

## ----plotLM2, fig.width=15-----------------------------------------------
plot(Ozone~Wind, data=airquality, pch="+")
abline(res$coefficients, col="blue", lwd=2)

## ----plotLM3, fig.width=20-----------------------------------------------
par(mfrow=c(1,2))
hist(res$residuals, col="grey")
plot(res$residuals~res$fitted, pch=19)

## ----testLM--------------------------------------------------------------
cor.test(airquality$Ozone, airquality$Wind)

## ----testLM2-------------------------------------------------------------
anova(res)

## ----predict-------------------------------------------------------------
predict(res, data.frame(Wind=c(5,20)))
# predict(res, c(5,20)) 
## does not work because 'Wind' is not set

## ----ex1-----------------------------------------------------------------
data(Orange)

## ----ex1-res1, results='hide', echo=FALSE--------------------------------
cor(Orange$age, Orange$circumference)

## ----ex1-res2, results='hide', echo=FALSE--------------------------------
cor.test(Orange$age, Orange$circumference)

## ----ex1-res3, results='hide', echo=FALSE--------------------------------
res <- lm(circumference~age, data=Orange)
res$coefficients

## ----ex1-res4, results='hide', echo=FALSE--------------------------------
predict(res, data.frame(age=median(Orange$age)))

## ----ex1-res5, echo=FALSE------------------------------------------------
par(bg="white")
plot(Orange$age, Orange$circumference, xlab="age", ylab="circumference", pch=19,
     main="Orange growth")
abline(res$coefficients, col="darkred", lty=2, lwd=2)
text(100, 200, 
     paste0("the equation is:\n y=", round(res$coefficients[1],2), "+",
            round(res$coefficients[2],2),"x"),
     pos=4, cex=2)

## ----ex1-randomSeed------------------------------------------------------
set.seed(1976)

## ----ex1-res6, echo=FALSE, results='hide', fig.height=5------------------
Orange$random <- rnorm(nrow(Orange), mean=mean(Orange$circumference),
                       sd=sd(Orange$circumference))
res2 <- lm(random~age, data=Orange)
cor.test(Orange$random, Orange$age)
par(bg="white")
plot(Orange$age, Orange$random, xlab="age", ylab="random numbers", pch=19,
     main="Orange pseudo-growth")
abline(res2$coefficients, col="darkred", lty=2, lwd=2)
text(100, 200, 
     paste0("the equation is:\n y=", round(res2$coefficients[1],2), "+",
            round(res2$coefficients[2],2),"x"),
     pos=4, cex=1.5)

